@@ -31,7 +31,7 @@
 #if defined VISUALC || defined BESTA_OS 
 typedef long pid_t;
 #else // VISUALC
-#if !defined(__MINGW_H) && !defined(NSPIRE) && !defined(__ANDROID__) && !defined(NSPIRE_NEWLIB) && !defined(OSX) && !defined(IOS) && !defined(FIR_LINUX)
+#if !defined(__MINGW_H) && !defined(NSPIRE) && !defined(__ANDROID__) && !defined(NSPIRE_NEWLIB) && !defined(OSX) && !defined(IOS) && !defined(OSXIOS) && !defined(FIR_LINUX)
 #include "wince_replacements.h"
 #endif
 #ifdef __MINGW_H
@@ -206,7 +206,6 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
     smallint=256, // max small int to make modular oply operations with int
     max_series_expansion_order=64, // max auto order for series expansion
     max_texpand_expansion_order=64,
-    series_default_order=20,
     max_numexp=100
   };
   extern const char cas_suffixe[];
@@ -291,7 +290,17 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
 #ifdef TIMEOUT
   void control_c();
 #else
+#if 0
 #define control_c() if (ctrl_c) { interrupted = true; CERR << "Throwing exception for user interruption." << std::endl; throw(std::runtime_error("Stopped by user interruption.")); }
+#else
+#define control_c() if (ctrl_c) { \
+interrupted = true; \
+std::string source_path = __FILE__; \
+std::string source_filename = source_path.substr(source_path.find_last_of("/\\") + 1); \
+CERR << "Throwing exception for user interruption (" << source_filename << ":" << __LINE__ << ")" << std::endl; \
+throw(std::runtime_error("Stopped by user interruption.")); \
+}
+#endif
 #endif // TIMEOUT
 #endif // !NSPIRE, !FIR
 
@@ -531,7 +540,7 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
     bool _keep_algext_;
     int _angle_mode_;
     int _bounded_function_no_;
-    int _series_flags_; // bit1= full simplify, bit2=1 for truncation, bit3=atan does not rewrite sin/cos to tan
+    int _series_flags_; // bit1= full simplify, bit2=1 for truncation, bit3=atan does not rewrite sin/cos to tan, bit4=no back conversion, bit5=write<<1,1>> with series_variable_name, bit 6=write O() instead of order_size
     int _step_infolevel_; 
     int _default_color_;
     double _epsilon_;
@@ -576,6 +585,8 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
     double _total_time_;
     void * _evaled_table_;
     void * _extra_ptr_;
+    char _series_variable_name_;
+    unsigned short _series_default_order_;
     global();  
     ~global();
     global & operator = (const global & g);
@@ -704,6 +715,12 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
   bool & approx_mode(GIAC_CONTEXT);
   void approx_mode(bool b,GIAC_CONTEXT);
 
+  char & series_variable_name(GIAC_CONTEXT);
+  void series_variable_name(char b,GIAC_CONTEXT);
+
+  unsigned short & series_default_order(GIAC_CONTEXT);
+  void series_default_order(unsigned short b,GIAC_CONTEXT);
+
   vecteur & history_in(GIAC_CONTEXT);
   vecteur & history_out(GIAC_CONTEXT);
 
